@@ -58,7 +58,7 @@ void NetMeter::checkevent( void ){
     stats.getline( buf, 256, ':' );
 
     // discard the dummy line so it does not screw things up.
-    if (strcmp(buf, " dummy") == 0) {
+    if (strstr(buf, "dummy") != NULL) {
       stats.ignore(256, '\n');
       continue;
     }
