@@ -232,10 +232,18 @@ void XWin::getResources( void ){
 
   // Get resources from the resource file
   XrmInitialize();
+#ifdef DEBIAN
+  *rfilename=0;
+#endif
   if ( getenv( "HOME" ) != NULL ){
     strcpy(rfilename, getenv("HOME"));
     strcat(rfilename, "/.Xdefaults");
   }
+#ifdef DEBIAN
+  int f; 
+  if (f=fopen(rfilename,"r"))
+    fclose(f);
+#endif
   else
     strcpy(rfilename, "/usr/lib/X11/app-defaults/XOSView" );
 
